"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.createFFmpegFlags = void 0;
const path = require("path");
const format_float_1 = require("./utilities/format-float");
const map_crop_option_to_video_filter_1 = require("./utilities/map-crop-option-to-video-filter");
const map_resize_option_to_video_filter_1 = require("./utilities/map-resize-option-to-video-filter");
const map_rotate_option_to_video_filter_1 = require("./utilities/map-rotate-option-to-video-filter");
const map_speed_option_to_audio_filter_1 = require("./utilities/map-speed-option-to-audio-filter");
const map_speed_option_to_video_filter_1 = require("./utilities/map-speed-option-to-video-filter");
const parse_trim_option_1 = require("./utilities/parse-trim-option");
function createFFmpegFlags(inputFile, { audio, crop, format, fps, resize, reverse, rotate, speed, trim, volume }) {
    const flags = {
        'an': null,
        'codec:a': 'copy',
        'codec:v': 'copy',
        'filter:a': [],
        'filter:v': [],
        'i': inputFile,
        'ss': null,
        'to': null
    };
    const originalFormat = path.extname(inputFile).slice(1);
    const isGif = originalFormat === 'gif' || format === 'gif';
    if (crop !== null) {
        flags['codec:v'] = null;
        flags['filter:v'].push(map_crop_option_to_video_filter_1.mapCropOptionToVideoFilter(crop));
    }
    if (fps !== null) {
        flags['codec:v'] = null;
        flags['filter:v'].push(`fps=fps=${fps}`);
    }
    if (resize !== null) {
        flags['codec:v'] = null;
        flags['filter:v'].push(map_resize_option_to_video_filter_1.mapResizeOptionToVideoFilter(resize));
    }
    if (reverse === true) {
        flags['codec:a'] = null;
        flags['codec:v'] = null;
        flags['filter:a'].push('areverse');
        flags['filter:v'].push('reverse');
    }
    if (rotate !== null) {
        flags['codec:v'] = null;
        flags['filter:v'].push(map_rotate_option_to_video_filter_1.mapRotateOptionToVideoFilter(rotate));
    }
    if (speed !== null && speed !== 1) {
        flags['codec:a'] = null;
        flags['codec:v'] = null;
        flags['filter:a'].push(map_speed_option_to_audio_filter_1.mapSpeedOptionToAudioFilter(speed));
        flags['filter:v'].push(map_speed_option_to_video_filter_1.mapSpeedOptionToVideoFilter(speed));
    }
    if (trim !== null) {
        const { startTimestamp, endTimestamp } = parse_trim_option_1.parseTrimOption(trim);
        flags['ss'] = startTimestamp;
        flags['to'] = endTimestamp;
    }
    if (volume !== null && volume !== 1) {
        flags['codec:a'] = null;
        flags['filter:a'].push(`volume=${format_float_1.formatFloat(volume)}`);
    }
    if (audio === false) {
        flags['an'] = true;
        flags['codec:a'] = null;
        flags['filter:a'] = [];
    }
    if (isGif === true) {
        flags['an'] = null;
        flags['codec:a'] = null;
        flags['codec:v'] = null;
        flags['filter:a'] = [];
    }
    return flags;
}
exports.createFFmpegFlags = createFFmpegFlags;
